This website requires JavaScript.
Explore
Help
Sign In
gptbot
/
0ad
Watch
1
Star
0
Fork
0
forked from
mirrors/0ad
Code
Pull Requests
Activity
Files
1c1200a04981acfb6cedefb08914cf2a47ef7748
0ad
/
source
/
ps
/
XML
T
History
Ykkrosh
bd2c1d73a3
Terrain, Interact, LOSManager, Atlas, etc: Fixed some off-by-one and off-by-FLT_EPSILON problems with objects near/off the edge of the map. Also changed some model.GetBounds().GetCentre() into model.GetTransform().GetTranslation() to fix off-by-centre-of-bounds-minus-position problems. Thus, you can no longer make units in Atlas disappear off the edge and never be seen or selected again. Also changed out-of-bounds LOS value to make them visible if they somehow escape anyway. Also fixed out-of-bounds access of terrain heightmap.
...
MapReader: Tidied usage of Xeromyces. Projectile: Avoided warnings. This was SVN commit r3212.
2005-12-09 01:08:08 +00:00
..
XercesErrorHandler.cpp
moved ps/X* to ps/XML/
2005-08-14 23:50:37 +00:00
XercesErrorHandler.h
moved ps/X* to ps/XML/
2005-08-14 23:50:37 +00:00
Xeromyces.cpp
profiling indicates memcpy is a bottleneck, so globally replace all of them with memcpy2 (hand-optimized). depending on transfer size, this is 10%..300% faster. also made memcpy2 into a macro instead of thunk function because vc7 was still generating a jump.
2005-10-30 16:19:20 +00:00
Xeromyces.h
moved ps/X* to ps/XML/
2005-08-14 23:50:37 +00:00
XeroXMB.cpp
moved ps/X* to ps/XML/
2005-08-14 23:50:37 +00:00
XeroXMB.h
Terrain, Interact, LOSManager, Atlas, etc: Fixed some off-by-one and off-by-FLT_EPSILON problems with objects near/off the edge of the map. Also changed some model.GetBounds().GetCentre() into model.GetTransform().GetTranslation() to fix off-by-centre-of-bounds-minus-position problems. Thus, you can no longer make units in Atlas disappear off the edge and never be seen or selected again. Also changed out-of-bounds LOS value to make them visible if they somehow escape anyway. Also fixed out-of-bounds access of terrain heightmap.
2005-12-09 01:08:08 +00:00
XML.h
moved ps/X* to ps/XML/
2005-08-14 23:50:37 +00:00
XMLUtils.cpp
profiling indicates memcpy is a bottleneck, so globally replace all of them with memcpy2 (hand-optimized). depending on transfer size, this is 10%..300% faster. also made memcpy2 into a macro instead of thunk function because vc7 was still generating a jump.
2005-10-30 16:19:20 +00:00
XMLWriter.cpp
various small fixes; some changes as in previous rev (which was only the files in lib/)
2005-12-07 03:44:17 +00:00
XMLWriter.h
moved ps/X* to ps/XML/
2005-08-14 23:50:37 +00:00